summaryrefslogtreecommitdiffstats
path: root/dbus/dbus-transport-protected.h
diff options
context:
space:
mode:
Diffstat (limited to 'dbus/dbus-transport-protected.h')
-rw-r--r--dbus/dbus-transport-protected.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/dbus/dbus-transport-protected.h b/dbus/dbus-transport-protected.h
index b60151ef..5a09d700 100644
--- a/dbus/dbus-transport-protected.h
+++ b/dbus/dbus-transport-protected.h
@@ -66,9 +66,9 @@ struct DBusTransportVTable
void (* live_messages_changed) (DBusTransport *transport);
/**< Outstanding messages counter changed */
- dbus_bool_t (* get_unix_fd) (DBusTransport *transport,
- int *fd_p);
- /**< Get UNIX file descriptor */
+ dbus_bool_t (* get_socket_fd) (DBusTransport *transport,
+ int *fd_p);
+ /**< Get socket file descriptor */
};
/**